# coding=utf-8
import requests


def get_coordinate(location):
    url_format = "http://api.map.baidu.com/geocoder/v2/?output=json&ak=SjDhGSaC0GTQfhL7ezS9Qb0MoTWk49hO&address=%s"
    url = url_format % location
    response = requests.get(url)
    answer = response.json()
    try:
        x, y = answer['result']['location']['lng'], answer['result']['location']['lat']
        return x, y
    except:
        print 'query location %s fail, %s' % (location, answer)
        return None, None



# coding=utf-8
import hashlib
import re


def gen_md5(text):
    m = hashlib.md5()
    m.update(text)
    return m.hexdigest()


def get_links(html):
    webpage_regex = re.compile('<a[^>]+href=["\'](.*?)["\']', re.IGNORECASE)
    return webpage_regex.findall(html)




# coding=utf-8
from bsddb import db


def get_db(db_filename):
    adb = db.DB()
    adb.open(db_filename, dbtype=db.DB_HASH, flags=db.DB_CREATE)
    return adb


def pop_from_db(adb):
    record = adb.cursor().first()
    if record is None:
        return None
    adb.delete(record[0])
    return record



# coding=utf-8
from selenium import webdriver


def get_headless_chrome():
    chrome_options = webdriver.ChromeOptions()
    chrome_options.add_argument('--headless')
    return webdriver.Chrome(chrome_options=chrome_options)
